plesk
    * ``auth_username`` Specify username for authentication

    * ``auth_password`` Specify password for authentication

    * ``plesk_server`` Specify url to the plesk web ui, including the port
